==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/OAuthTemplatesFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OAuthTemplatesFluentImpl<A extends OAuthTemplatesFluent<A>> extends BaseFluent<A> implements OAuthTemplatesFluent<A>{
  public OAuthTemplatesFluentImpl() {
  }
  public OAuthTemplatesFluentImpl(OAuthTemplates instance) {
    this.withError(instance.getError()); 
    this.withLogin(instance.getLogin()); 
    this.withProviderSelection(instance.getProviderSelection()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private SecretNameReferenceBuilder error;
  private SecretNameReferenceBuilder login;
  private SecretNameReferenceBuilder providerSelection;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildError instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getError() {
    return this.error!=null ?this.error.build():null;
  }
  public SecretNameReference buildError() {
    return this.error!=null ?this.error.build():null;
  }
  public A withError(SecretNameReference error) {
    _visitables.get("error").remove(this.error);
    if (error!=null){ this.error= new SecretNameReferenceBuilder(error); _visitables.get("error").add(this.error);} else { this.error = null; _visitables.get("error").remove(this.error); } return (A) this;
  }
  public Boolean hasError() {
    return this.error != null;
  }
  public A withNewError(String name) {
    return (A)withError(new SecretNameReference(name));
  }
  public OAuthTemplatesFluent.ErrorNested<A> withNewError() {
    return new OAuthTemplatesFluentImpl.ErrorNestedImpl();
  }
  public OAuthTemplatesFluent.ErrorNested<A> withNewErrorLike(SecretNameReference item) {
    return new OAuthTemplatesFluentImpl.ErrorNestedImpl(item);
  }
  public OAuthTemplatesFluent.ErrorNested<A> editError() {
    return withNewErrorLike(getError());
  }
  public OAuthTemplatesFluent.ErrorNested<A> editOrNewError() {
    return withNewErrorLike(getError() != null ? getError(): new SecretNameReferenceBuilder().build());
  }
  public OAuthTemplatesFluent.ErrorNested<A> editOrNewErrorLike(SecretNameReference item) {
    return withNewErrorLike(getError() != null ? getError(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildLogin instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getLogin() {
    return this.login!=null ?this.login.build():null;
  }
  public SecretNameReference buildLogin() {
    return this.login!=null ?this.login.build():null;
  }
  public A withLogin(SecretNameReference login) {
    _visitables.get("login").remove(this.login);
    if (login!=null){ this.login= new SecretNameReferenceBuilder(login); _visitables.get("login").add(this.login);} else { this.login = null; _visitables.get("login").remove(this.login); } return (A) this;
  }
  public Boolean hasLogin() {
    return this.login != null;
  }
  public A withNewLogin(String name) {
    return (A)withLogin(new SecretNameReference(name));
  }
  public OAuthTemplatesFluent.LoginNested<A> withNewLogin() {
    return new OAuthTemplatesFluentImpl.LoginNestedImpl();
  }
  public OAuthTemplatesFluent.LoginNested<A> withNewLoginLike(SecretNameReference item) {
    return new OAuthTemplatesFluentImpl.LoginNestedImpl(item);
  }
  public OAuthTemplatesFluent.LoginNested<A> editLogin() {
    return withNewLoginLike(getLogin());
  }
  public OAuthTemplatesFluent.LoginNested<A> editOrNewLogin() {
    return withNewLoginLike(getLogin() != null ? getLogin(): new SecretNameReferenceBuilder().build());
  }
  public OAuthTemplatesFluent.LoginNested<A> editOrNewLoginLike(SecretNameReference item) {
    return withNewLoginLike(getLogin() != null ? getLogin(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildProviderSelection instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getProviderSelection() {
    return this.providerSelection!=null ?this.providerSelection.build():null;
  }
  public SecretNameReference buildProviderSelection() {
    return this.providerSelection!=null ?this.providerSelection.build():null;
  }
  public A withProviderSelection(SecretNameReference providerSelection) {
    _visitables.get("providerSelection").remove(this.providerSelection);
    if (providerSelection!=null){ this.providerSelection= new SecretNameReferenceBuilder(providerSelection); _visitables.get("providerSelection").add(this.providerSelection);} else { this.providerSelection = null; _visitables.get("providerSelection").remove(this.providerSelection); } return (A) this;
  }
  public Boolean hasProviderSelection() {
    return this.providerSelection != null;
  }
  public A withNewProviderSelection(String name) {
    return (A)withProviderSelection(new SecretNameReference(name));
  }
  public OAuthTemplatesFluent.ProviderSelectionNested<A> withNewProviderSelection() {
    return new OAuthTemplatesFluentImpl.ProviderSelectionNestedImpl();
  }
  public OAuthTemplatesFluent.ProviderSelectionNested<A> withNewProviderSelectionLike(SecretNameReference item) {
    return new OAuthTemplatesFluentImpl.ProviderSelectionNestedImpl(item);
  }
  public OAuthTemplatesFluent.ProviderSelectionNested<A> editProviderSelection() {
    return withNewProviderSelectionLike(getProviderSelection());
  }
  public OAuthTemplatesFluent.ProviderSelectionNested<A> editOrNewProviderSelection() {
    return withNewProviderSelectionLike(getProviderSelection() != null ? getProviderSelection(): new SecretNameReferenceBuilder().build());
  }
  public OAuthTemplatesFluent.ProviderSelectionNested<A> editOrNewProviderSelectionLike(SecretNameReference item) {
    return withNewProviderSelectionLike(getProviderSelection() != null ? getProviderSelection(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OAuthTemplatesFluentImpl that = (OAuthTemplatesFluentImpl) o;
    if (error != null ? !error.equals(that.error) :that.error != null) return false;
    if (login != null ? !login.equals(that.login) :that.login != null) return false;
    if (providerSelection != null ? !providerSelection.equals(that.providerSelection) :that.providerSelection != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(error,  login,  providerSelection,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (error != null) { sb.append("error:"); sb.append(error + ","); }
    if (login != null) { sb.append("login:"); sb.append(login + ","); }
    if (providerSelection != null) { sb.append("providerSelection:"); sb.append(providerSelection + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ErrorNestedImpl<N> extends SecretNameReferenceFluentImpl<OAuthTemplatesFluent.ErrorNested<N>> implements OAuthTemplatesFluent.ErrorNested<N>,Nested<N>{
    ErrorNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    ErrorNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluentImpl.this.withError(builder.build());
    }
    public N endError() {
      return and();
    }
    
  }
  class LoginNestedImpl<N> extends SecretNameReferenceFluentImpl<OAuthTemplatesFluent.LoginNested<N>> implements OAuthTemplatesFluent.LoginNested<N>,Nested<N>{
    LoginNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    LoginNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluentImpl.this.withLogin(builder.build());
    }
    public N endLogin() {
      return and();
    }
    
  }
  class ProviderSelectionNestedImpl<N> extends SecretNameReferenceFluentImpl<OAuthTemplatesFluent.ProviderSelectionNested<N>> implements OAuthTemplatesFluent.ProviderSelectionNested<N>,Nested<N>{
    ProviderSelectionNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    ProviderSelectionNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluentImpl.this.withProviderSelection(builder.build());
    }
    public N endProviderSelection() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/OAuthTemplatesFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OAuthTemplatesFluentImpl<A extends OAuthTemplatesFluent<A>> extends BaseFluent<A> implements OAuthTemplatesFluent<A>{
  public OAuthTemplatesFluentImpl() {
  }
  public OAuthTemplatesFluentImpl(OAuthTemplates instance) {
    if (instance != null) {
      this.withError(instance.getError());
      this.withLogin(instance.getLogin());
      this.withProviderSelection(instance.getProviderSelection());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private SecretNameReferenceBuilder error;
  private SecretNameReferenceBuilder login;
  private SecretNameReferenceBuilder providerSelection;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildError instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getError() {
    return this.error!=null ?this.error.build():null;
  }
  public SecretNameReference buildError() {
    return this.error!=null ?this.error.build():null;
  }
  public A withError(SecretNameReference error) {
    _visitables.get("error").remove(this.error);
    if (error!=null){ this.error= new SecretNameReferenceBuilder(error); _visitables.get("error").add(this.error);} else { this.error = null; _visitables.get("error").remove(this.error); } return (A) this;
  }
  public Boolean hasError() {
    return this.error != null;
  }
  public A withNewError(String name) {
    return (A)withError(new SecretNameReference(name));
  }
  public OAuthTemplatesFluentImpl.ErrorNested<A> withNewError() {
    return new OAuthTemplatesFluentImpl.ErrorNestedImpl();
  }
  public OAuthTemplatesFluentImpl.ErrorNested<A> withNewErrorLike(SecretNameReference item) {
    return new OAuthTemplatesFluentImpl.ErrorNestedImpl(item);
  }
  public OAuthTemplatesFluentImpl.ErrorNested<A> editError() {
    return withNewErrorLike(getError());
  }
  public OAuthTemplatesFluentImpl.ErrorNested<A> editOrNewError() {
    return withNewErrorLike(getError() != null ? getError(): new SecretNameReferenceBuilder().build());
  }
  public OAuthTemplatesFluentImpl.ErrorNested<A> editOrNewErrorLike(SecretNameReference item) {
    return withNewErrorLike(getError() != null ? getError(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildLogin instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getLogin() {
    return this.login!=null ?this.login.build():null;
  }
  public SecretNameReference buildLogin() {
    return this.login!=null ?this.login.build():null;
  }
  public A withLogin(SecretNameReference login) {
    _visitables.get("login").remove(this.login);
    if (login!=null){ this.login= new SecretNameReferenceBuilder(login); _visitables.get("login").add(this.login);} else { this.login = null; _visitables.get("login").remove(this.login); } return (A) this;
  }
  public Boolean hasLogin() {
    return this.login != null;
  }
  public A withNewLogin(String name) {
    return (A)withLogin(new SecretNameReference(name));
  }
  public OAuthTemplatesFluentImpl.LoginNested<A> withNewLogin() {
    return new OAuthTemplatesFluentImpl.LoginNestedImpl();
  }
  public OAuthTemplatesFluentImpl.LoginNested<A> withNewLoginLike(SecretNameReference item) {
    return new OAuthTemplatesFluentImpl.LoginNestedImpl(item);
  }
  public OAuthTemplatesFluentImpl.LoginNested<A> editLogin() {
    return withNewLoginLike(getLogin());
  }
  public OAuthTemplatesFluentImpl.LoginNested<A> editOrNewLogin() {
    return withNewLoginLike(getLogin() != null ? getLogin(): new SecretNameReferenceBuilder().build());
  }
  public OAuthTemplatesFluentImpl.LoginNested<A> editOrNewLoginLike(SecretNameReference item) {
    return withNewLoginLike(getLogin() != null ? getLogin(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildProviderSelection instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getProviderSelection() {
    return this.providerSelection!=null ?this.providerSelection.build():null;
  }
  public SecretNameReference buildProviderSelection() {
    return this.providerSelection!=null ?this.providerSelection.build():null;
  }
  public A withProviderSelection(SecretNameReference providerSelection) {
    _visitables.get("providerSelection").remove(this.providerSelection);
    if (providerSelection!=null){ this.providerSelection= new SecretNameReferenceBuilder(providerSelection); _visitables.get("providerSelection").add(this.providerSelection);} else { this.providerSelection = null; _visitables.get("providerSelection").remove(this.providerSelection); } return (A) this;
  }
  public Boolean hasProviderSelection() {
    return this.providerSelection != null;
  }
  public A withNewProviderSelection(String name) {
    return (A)withProviderSelection(new SecretNameReference(name));
  }
  public OAuthTemplatesFluentImpl.ProviderSelectionNested<A> withNewProviderSelection() {
    return new OAuthTemplatesFluentImpl.ProviderSelectionNestedImpl();
  }
  public OAuthTemplatesFluentImpl.ProviderSelectionNested<A> withNewProviderSelectionLike(SecretNameReference item) {
    return new OAuthTemplatesFluentImpl.ProviderSelectionNestedImpl(item);
  }
  public OAuthTemplatesFluentImpl.ProviderSelectionNested<A> editProviderSelection() {
    return withNewProviderSelectionLike(getProviderSelection());
  }
  public OAuthTemplatesFluentImpl.ProviderSelectionNested<A> editOrNewProviderSelection() {
    return withNewProviderSelectionLike(getProviderSelection() != null ? getProviderSelection(): new SecretNameReferenceBuilder().build());
  }
  public OAuthTemplatesFluentImpl.ProviderSelectionNested<A> editOrNewProviderSelectionLike(SecretNameReference item) {
    return withNewProviderSelectionLike(getProviderSelection() != null ? getProviderSelection(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OAuthTemplatesFluentImpl that = (OAuthTemplatesFluentImpl) o;
    if (!java.util.Objects.equals(error, that.error)) return false;

    if (!java.util.Objects.equals(login, that.login)) return false;

    if (!java.util.Objects.equals(providerSelection, that.providerSelection)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(error,  login,  providerSelection,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (error != null) { sb.append("error:"); sb.append(error + ","); }
    if (login != null) { sb.append("login:"); sb.append(login + ","); }
    if (providerSelection != null) { sb.append("providerSelection:"); sb.append(providerSelection + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ErrorNestedImpl<N> extends SecretNameReferenceFluentImpl<OAuthTemplatesFluentImpl.ErrorNested<N>> implements OAuthTemplatesFluentImpl.ErrorNested<N>,Nested<N>{
    ErrorNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    ErrorNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluentImpl.this.withError(builder.build());
    }
    public N endError() {
      return and();
    }
    
  }
  class LoginNestedImpl<N> extends SecretNameReferenceFluentImpl<OAuthTemplatesFluentImpl.LoginNested<N>> implements OAuthTemplatesFluentImpl.LoginNested<N>,Nested<N>{
    LoginNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    LoginNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluentImpl.this.withLogin(builder.build());
    }
    public N endLogin() {
      return and();
    }
    
  }
  class ProviderSelectionNestedImpl<N> extends SecretNameReferenceFluentImpl<OAuthTemplatesFluentImpl.ProviderSelectionNested<N>> implements OAuthTemplatesFluentImpl.ProviderSelectionNested<N>,Nested<N>{
    ProviderSelectionNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    ProviderSelectionNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluentImpl.this.withProviderSelection(builder.build());
    }
    public N endProviderSelection() {
      return and();
    }
    
  }
  
}
